<?php
$TRANSLATIONS = array(
"Invalid value supplied for %s" => "Se introdujo un valor inválido para %s",
"Saved" => "Guardado",
"test email settings" => "probar configuración de correo",
"If you received this email, the settings seem to be correct." => "Si recibió este mensaje de correo electrónico, su configuración debe estar correcta.",
"A problem occurred while sending the e-mail. Please revisit your settings." => "Ocurrió un problema la enviar el mensaje. Revise la configuración.",
"Email sent" => "Correo electrónico enviado",
"You need to set your user email before being able to send test emails." => "Tiene que configurar su dirección de correo electrónico antes de poder enviar mensajes de prueba.",
"Send mode" => "Modo de envío",
"Encryption" => "Cifrado",
"Authentication method" => "Método de autenticación",
"Unable to load list from App Store" => "No se pudo cargar la lista desde el App Store",
"Authentication error" => "Error de autenticación",
"Your full name has been changed." => "Se ha cambiado su nombre completo.",
"Unable to change full name" => "No se puede cambiar el nombre completo",
"Group already exists" => "El grupo ya existe",
"Unable to add group" => "No se pudo añadir el grupo",
"Files decrypted successfully" => "Los archivos fueron descifrados",
"Couldn't decrypt your files, please check your owncloud.log or ask your administrator" => "No se pudo descifrar sus archivos. Revise el owncloud.log o consulte con su administrador",
"Couldn't decrypt your files, check your password and try again" => "No se pudo descifrar sus archivos. Revise su contraseña e inténtelo de nuevo",
"Encryption keys deleted permanently" => "Claves de cifrado eliminadas permanentemente",
"Couldn't permanently delete your encryption keys, please check your owncloud.log or ask your administrator" => "No se pudieron eliminar permanentemente sus claves de cifrado. Revise owncloud.log o consulte con su administrador.",
"Couldn't remove app." => "No se pudo eliminar la aplicación.",
"Email saved" => "Correo electrónico guardado",
"Invalid email" => "Correo electrónico no válido",
"Unable to delete group" => "No se pudo eliminar el grupo",
"Unable to delete user" => "No se pudo eliminar el usuario",
"Backups restored successfully" => "Copia de seguridad restaurada",
"Couldn't restore your encryption keys, please check your owncloud.log or ask your administrator" => "No se pudieron restarurar sus claves de cifrado. Revise owncloud.log o consulte con su administrador.",
"Language changed" => "Idioma cambiado",
"Invalid request" => "Petición no válida",
"Admins can't remove themself from the admin group" => "Los administradores no se pueden eliminar a ellos mismos del grupo de administrador",
"Unable to add user to group %s" => "No se pudo añadir el usuario al grupo %s",
"Unable to remove user from group %s" => "No se pudo eliminar al usuario del grupo %s",
"Couldn't update app." => "No se pudo actualizar la aplicación.",
"Wrong password" => "Contraseña incorrecta",
"No user supplied" => "No se especificó un usuario",
"Please provide an admin recovery password, otherwise all user data will be lost" => "Por favor facilite una contraseña de recuperación de administrador, sino podrían perderse todos los datos de usuario",
"Wrong admin recovery password. Please check the password and try again." => "Contraseña de recuperación de administrador incorrecta. Por favor compruebe la contraseña e inténtelo de nuevo.",
"Back-end doesn't support password change, but the users encryption key was successfully updated." => "El back-end no soporta cambios de contraseña, pero la clave de cifrado del usuario ha sido actualizada satisfactoriamente.",
"Unable to change password" => "No se ha podido cambiar la contraseña",
"Sending..." => "Enviando...",
"User Documentation" => "Documentación de usuario",
"Admin Documentation" => "Documentación para administradores",
"Update to {appversion}" => "Actualizar a {appversion}",
"Uninstall App" => "Desinstalar aplicación",
"Disable" => "Desactivar",
"Enable" => "Activar",
"Please wait...." => "Espere, por favor....",
"Error while disabling app" => "Error mientras se desactivaba la aplicación",
"Error while enabling app" => "Error mientras se activaba la aplicación",
"Updating...." => "Actualizando....",
"Error while updating app" => "Error mientras se actualizaba la aplicación",
"Error" => "Error",
"Update" => "Actualizar",
"Updated" => "Actualizado",
"Uninstalling ...." => "Desinstalando...",
"Error while uninstalling app" => "Error al desinstalar la aplicación",
"Uninstall" => "Desinstalar",
"Select a profile picture" => "Seleccionar una imagen de perfil",
"Very weak password" => "Contraseña muy débil",
"Weak password" => "Contraseña débil",
"So-so password" => "Contraseña pasable",
"Good password" => "Contraseña buena",
"Strong password" => "Contraseña muy buena",
"Decrypting files... Please wait, this can take some time." => "Descifrando archivos... Espere por favor, esto puede llevar algo de tiempo.",
"Delete encryption keys permanently." => "Eliminar claves de cifrado permanentemente.",
"Restore encryption keys." => "Restaurar claves de cifrado.",
"Unable to delete {objName}" => "No es posible eliminar {objName}",
"Error creating group" => "Error al crear un grupo",
"A valid group name must be provided" => "Se debe dar un nombre válido para el grupo ",
"deleted {groupName}" => "borrado {groupName}",
"undo" => "deshacer",
"Groups" => "Grupos",
"Group Admin" => "Administrador del Grupo",
"Delete" => "Eliminar",
"never" => "nunca",
"deleted {userName}" => "borrado {userName}",
"add group" => "añadir Grupo",
"A valid username must be provided" => "Se debe proporcionar un nombre de usuario válido",
"Error creating user" => "Error al crear usuario",
"A valid password must be provided" => "Se debe proporcionar una contraseña válida",
"Warning: Home directory for user \"{user}\" already exists" => "Atención: el directorio de inicio para el usuario \"{user}\" ya existe.",
"__language_name__" => "Castellano",
"Everything (fatal issues, errors, warnings, info, debug)" => "Todo (Información, Avisos, Errores, debug y problemas fatales)",
"Info, warnings, errors and fatal issues" => "Información, Avisos, Errores y problemas fatales",
"Warnings, errors and fatal issues" => "Advertencias, errores y problemas fatales",
"Errors and fatal issues" => "Errores y problemas fatales",
"Fatal issues only" => "Problemas fatales solamente",
"None" => "Ninguno",
"Login" => "Iniciar sesión",
"Plain" => "Plano",
"NT LAN Manager" => "Gestor de NT LAN",
"SSL" => "SSL",
"TLS" => "TLS",
"Security Warning" => "Advertencia de seguridad",
"You are accessing %s via HTTP. We strongly suggest you configure your server to require using HTTPS instead." => "Está ingresando a %s vía HTTP. Le recomendamos encarecidamente que configure su servidor para que requiera HTTPS.",
"Your data directory and your files are probably accessible from the internet. The .htaccess file is not working. We strongly suggest that you configure your webserver in a way that the data directory is no longer accessible or you move the data directory outside the webserver document root." => "Su directorio de datos y archivos es probablemente accesible desde Internet pues el archivo .htaccess no está funcionando. Le sugerimos encarecidamente que configure su servidor web de modo que el directorio de datos no sea accesible o que mueva dicho directorio fuera de la raíz de documentos del servidor web.",
"Setup Warning" => "Advertencia de configuración",
"Your web server is not yet properly setup to allow files synchronization because the WebDAV interface seems to be broken." => "Su servidor web aún no está configurado adecuadamente para permitir la sincronización de archivos ya que la interfaz WebDAV parece no estar funcionando.",
"Please double check the <a href=\"%s\">installation guides</a>." => "Por favor, vuelva a comprobar las <a href='%s'>guías de instalación</a>.",
"PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." => "PHP está aparentemente configurado para eliminar bloques de documentos en línea. Esto hará que varias aplicaciones del principales no estén accesibles.",
"This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." => "Probablemente esto sea causado por un cache o acelerador, como por ejemplo Zend OPcache o eAccelerator.",
"Database Performance Info" => "Información de rendimiento de la base de datos",
"SQLite is used as database. For larger installations we recommend to change this. To migrate to another database use the command line tool: 'occ db:convert-type'" => "Se está usando SQLite como base de datos. Para instalaciones más grandes, recomendamos cambiar esto. Para migrar a otra base de datos, use la herramienta de línea de comandos: 'occ db:convert-type'",
"Module 'fileinfo' missing" => "No se ha encontrado el módulo \"fileinfo\"",
"The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." => "No se ha encontrado el modulo PHP 'fileinfo'. Le recomendamos encarecidamente que habilite este módulo para obtener mejores resultados con la detección de tipos MIME.",
"Your PHP version is outdated" => "Su versión de PHP no está actualizada",
"Your PHP version is outdated. We strongly recommend to update to 5.3.8 or newer because older versions are known to be broken. It is possible that this installation is not working correctly." => "Su versión de PHP ha caducado. Le sugerimos encarecidamente que la actualize a 5.3.8 o a una más nueva porque normalmente las versiones antiguas no funcionan bien. Puede ser que esta instalación no esté funcionando bien por ello.",
"Locale not working" => "La configuración regional no está funcionando",
"System locale can not be set to a one which supports UTF-8." => "No se puede escoger una configuración regional que soporte UTF-8.",
"This means that there might be problems with certain characters in file names." => "Esto significa que puede haber problemas con ciertos caracteres en los nombres de los archivos.",
"We strongly suggest to install the required packages on your system to support one of the following locales: %s." => "Es muy recomendable instalar los paquetes necesarios para poder soportar una de las siguientes configuraciones regionales: %s. ",
"Internet connection not working" => "La conexión a Internet no está funcionando",
"This server has no working internet connection. This means that some of the features like mounting of external storage, notifications about updates or installation of 3rd party apps don´t work. Accessing files from remote and sending of notification emails might also not work. We suggest to enable internet connection for this server if you want to have all features." => "Este servidor no tiene conexión a Internet. Esto significa que algunas de las características no funcionarán, como el montaje de almacenamiento externo, las notificaciones sobre actualizaciones, la instalación de aplicaciones de terceros, el acceso a los archivos de forma remota o el envío de correos electrónicos de notificación. Sugerimos habilitar una conexión a Internet en este servidor para disfrutar de todas las funciones.",
"Cron" => "Cron",
"Last cron was executed at %s." => "Cron fue ejecutado por última vez a las %s.",
"Last cron was executed at %s. This is more than an hour ago, something seems wrong." => "Cron fue ejecutado por última vez a las %s. Esto fue hace más de una hora, algo anda mal.",
"Cron was not executed yet!" => "¡Cron aún no ha sido ejecutado!",
"Execute one task with each page loaded" => "Ejecutar una tarea con cada página cargada",
"cron.php is registered at a webcron service to call cron.php every 15 minutes over http." => "cron.php se registra en un servicio webcron para llamar a cron.php cada 15 minutos a través de HTTP.",
"Use system's cron service to call the cron.php file every 15 minutes." => "Utiliza el servicio cron del sistema para llamar al archivo cron.php cada 15 minutos.",
"Sharing" => "Compartiendo",
"Allow apps to use the Share API" => "Permitir a las aplicaciones utilizar la API de Compartición",
"Allow users to share via link" => "Permite a los usuarios compartir por medio de enlaces",
"Enforce password protection" => "Mejora la protección por contraseña.",
"Allow public uploads" => "Permitir subidas públicas",
"Set default expiration date" => "Establecer fecha de caducidad predeterminada",
"Expire after " => "Caduca luego de",
"days" => "días",
"Enforce expiration date" => "Imponer fecha de caducidad",
"Allow resharing" => "Permitir re-compartición",
"Restrict users to only share with users in their groups" => "Restringe a los usuarios a compartir solo con otros usuarios en sus grupos",
"Allow users to send mail notification for shared files" => "Permitir a los usuarios enviar mensajes de notificación para ficheros compartidos",
"Exclude groups from sharing" => "Excluye grupos de compartir",
"These groups will still be able to receive shares, but not to initiate them." => "Estos grupos aún podrán recibir contenidos compartidos, pero no podrán, pero no podrán iniciarlos.",
"Security" => "Seguridad",
"Enforce HTTPS" => "Forzar HTTPS",
"Forces the clients to connect to %s via an encrypted connection." => "Forzar a los clientes a conectarse a %s por medio de una conexión cifrada.",
"Please connect to your %s via HTTPS to enable or disable the SSL enforcement." => "Por favor, conéctese a su %s a través de HTTPS para habilitar o deshabilitar la aplicación de SSL.",
"Email Server" => "Servidor de correo electrónico",
"This is used for sending out notifications." => "Esto se usa para enviar notificaciones.",
"From address" => "Desde la dirección",
"mail" => "correo electrónico",
"Authentication required" => "Se necesita autenticación",
"Server address" => "Dirección del servidor",
"Port" => "Puerto",
"Credentials" => "Credenciales",
"SMTP Username" => "Nombre de usuario SMTP",
"SMTP Password" => "Contraseña SMTP",
"Test email settings" => "Probar configuración de correo electrónico",
"Send email" => "Enviar mensaje",
"Log" => "Registro",
"Log level" => "Nivel de registro",
"More" => "Más",
"Less" => "Menos",
"Version" => "Versión",
"Developed by the <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud community</a>, the <a href=\"https://github.com/owncloud\" target=\"_blank\">source code</a> is licensed under the <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>." => "Desarrollado por la <a href=\"http://ownCloud.org/contact\" target=\"_blank\">comunidad ownCloud</a>, el <a href=\"https://github.com/owncloud\" target=\"_blank\">código fuente</a> está bajo licencia <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>.",
"Add your App" => "Añade tu aplicación",
"More Apps" => "Más aplicaciones",
"Select an App" => "Seleccionar una aplicación",
"Documentation:" => "Documentación:",
"See application page at apps.owncloud.com" => "Ver la página de aplicaciones en apps.owncloud.com",
"See application website" => "Ver sitio web de la aplicación",
"<span class=\"licence\"></span>-licensed by <span class=\"author\"></span>" => "<span class=\"licence\"></span>-licencia otorgada por <span class=\"author\"></span>",
"Enable only for specific groups" => "Activar solamente para grupos específicos",
"All" => "Todos",
"Administrator Documentation" => "Documentación de administrador",
"Online Documentation" => "Documentación en línea",
"Forum" => "Foro",
"Bugtracker" => "Rastreador de fallos",
"Commercial Support" => "Soporte comercial",
"Get the apps to sync your files" => "Obtener las aplicaciones para sincronizar sus archivos",
"Show First Run Wizard again" => "Mostrar nuevamente el Asistente de ejecución inicial",
"You have used <strong>%s</strong> of the available <strong>%s</strong>" => "Ha usado <strong>%s</strong> de los <strong>%s</strong> disponibles",
"Password" => "Contraseña",
"Your password was changed" => "Su contraseña ha sido cambiada",
"Unable to change your password" => "No se ha podido cambiar su contraseña",
"Current password" => "Contraseña actual",
"New password" => "Nueva contraseña",
"Change password" => "Cambiar contraseña",
"Full Name" => "Nombre completo",
"Email" => "Correo electrónico",
"Your email address" => "Su dirección de correo",
"Fill in an email address to enable password recovery and receive notifications" => "Introducir una dirección de correo electrónico  para activar la recuperación de contraseñas y recibir notificaciones",
"Profile picture" => "Foto de perfil",
"Upload new" => "Subir otra",
"Select new from Files" => "Seleccionar otra desde Archivos",
"Remove image" => "Borrar imagen",
"Either png or jpg. Ideally square but you will be able to crop it." => "Archivo PNG o JPG. Preferiblemente cuadrado, pero tendrás la posibilidad de recortarlo.",
"Your avatar is provided by your original account." => "Su avatar es proporcionado por su cuenta original.",
"Cancel" => "Cancelar",
"Choose as profile image" => "Seleccionar como imagen de perfil",
"Language" => "Idioma",
"Help translate" => "Ayúdanos a traducir",
"The encryption app is no longer enabled, please decrypt all your files" => "La aplicación de cifrado ya no está activada, descifre todos sus archivos",
"Log-in password" => "Contraseña de acceso",
"Decrypt all Files" => "Descifrar archivos",
"Your encryption keys are moved to a backup location. If something went wrong you can restore the keys. Only delete them permanently if you are sure that all files are decrypted correctly." => "Sus claves de cifrado se archivarán en una localización segura. Así en caso de que algo fuese mal podrá recuperan sus claves. Borre sus claves de cifrado permanentemente solamente si esta seguro de que sus archivos han sido descifrados correctamente.",
"Restore Encryption Keys" => "Restaurar claves de cifrado",
"Delete Encryption Keys" => "Eliminar claves de cifrado",
"Login Name" => "Nombre de usuario",
"Create" => "Crear",
"Admin Recovery Password" => "Recuperación de la contraseña de administración",
"Enter the recovery password in order to recover the users files during password change" => "Introduzca la contraseña de recuperación a fin de recuperar los archivos de los usuarios durante el cambio de contraseña.",
"Search Users and Groups" => "Buscar usuarios y grupos",
"Add Group" => "Agregar grupo",
"Group" => "Grupo",
"Everyone" => "Todos",
"Admins" => "Administradores",
"Default Quota" => "Cuota predeterminada",
"Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" => "Por favor indique la cúota de almacenamiento (ej: \"512 MB\" o \"12 GB\")",
"Unlimited" => "Ilimitado",
"Other" => "Otro",
"Username" => "Nombre de usuario",
"Quota" => "Cuota",
"Storage Location" => "Ubicación de almacenamiento",
"Last Login" => "Último inicio de sesión",
"change full name" => "cambiar el nombre completo",
"set new password" => "establecer nueva contraseña",
"Default" => "Predeterminado",
"If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwritewebroot\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" => "Si su instalación no está ubicada en la raíz del dominio y usa el cron del sistema, puede haber problemas al generarse los URL. Para evitarlos, configure la opción \"overwritewebroot\" en su archivo config.php para que use la ruta de la raíz del sitio web de su instalación (sugerencia: \"%s\")",
"URL generation in notification emails" => "Generación de URL en mensajes de notificación",
"Connectivity Checks" => "Probar la Conectividad",
"No problems found" => "No se han encontrado problemas",
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
